==> tencentcloud-sdk-java-3.1.310-sources.jar: com/tencentcloudapi/dts/v20180330/DtsErrorCode.java <==
package com.tencentcloudapi.dts.v20180330;
public enum DtsErrorCode {
    // 禁止该操作。
     FAILEDOPERATION_NOTALLOWOPERATION("FailedOperation.NotAllowOperation"),
     
    // 任务开始失败。
     FAILEDOPERATION_STARTJOBFAILED("FailedOperation.StartJobFailed"),
     
    // 当前状态冲突，不能执行该操作。
     FAILEDOPERATION_STATUSINCONFLICT("FailedOperation.StatusInConflict"),
     
    // 内部错误。
     INTERNALERROR("InternalError"),
     
    // 添加异步任务失败。
     INTERNALERROR_ADDTASKERROR("InternalError.AddTaskError"),
     
    // cgw系统错误。
     INTERNALERROR_CGWSYSTEMERROR("InternalError.CgwSystemError"),
     
    // 迁移平台数据库访问失败。
     INTERNALERROR_DATABASEERROR("InternalError.DatabaseError"),
     
    // 迁移任务冲突。
     INTERNALERROR_DUPLICATEJOB("InternalError.DuplicateJob"),
     
    // 锁冲突。
     INTERNALERROR_LOCKERROR("InternalError.LockError"),
     
    // 通信协议错误。
     INTERNALERROR_PROTOCOLERROR("InternalError.ProtocolError"),
     
    // 参数错误。
     INVALIDPARAMETER("InvalidParameter"),
     
    // 实例不存在。
     INVALIDPARAMETER_INSTANCENOTFOUND("InvalidParameter.InstanceNotFound"),
     
    // 参数值错误。
     INVALIDPARAMETERVALUE_INVALIDPARAMETERVALUE("InvalidParameterValue.InvalidParameterValue"),
     
    // 闲置迁移任务数目超过限制。
     LIMITEXCEEDED_MAXUNUSEDJOBS("LimitExceeded.MaxUnusedJobs"),
     
    // 操作被拒绝。
     OPERATIONDENIED("OperationDenied"),
     
    // 该操作不能执行。
     OPERATIONDENIED_OPERATIONDENIED("OperationDenied.OperationDenied"),
     
    // 资源不存在。
     RESOURCENOTFOUND("ResourceNotFound"),
     
    // 迁移任务不存在。
     RESOURCENOTFOUND_JOBNOTEXIST("ResourceNotFound.JobNotExist"),
     
    // 实例未找到。
     RESOURCENOTFOUND_RESOURCENOTFOUND("ResourceNotFound.ResourceNotFound"),
     
    // 认证失败，没有足够权限。
     UNAUTHORIZEDOPERATION_NOTENOUGHPRIVILEGES("UnauthorizedOperation.NotEnoughPrivileges"),
     
    // 操作不支持。
     UNSUPPORTEDOPERATION("UnsupportedOperation"),
     
    // 当前实例类型不支持该操作。
     UNSUPPORTEDOPERATION_ACTIONNOTSUPPORT("UnsupportedOperation.ActionNotSupport");
     
    private String value;
    private DtsErrorCode (String value){
        this.value = value;
    }
    /**
     * @return errorcode value
     */
    public String getValue() {
        return value;
    }
}

==> tencentcloud-sdk-java-3.1.425-sources.jar: com/tencentcloudapi/dts/v20180330/DtsErrorCode.java <==
package com.tencentcloudapi.dts.v20180330;
public enum DtsErrorCode {
    // 鉴权失败，当前用户不允许执行该操作。
     AUTHFAILURE_UNAUTHORIZEDOPERATIONERROR("AuthFailure.UnauthorizedOperationError"),
     
    // 禁止该操作。
     FAILEDOPERATION_NOTALLOWOPERATION("FailedOperation.NotAllowOperation"),
     
    // 任务开始失败。
     FAILEDOPERATION_STARTJOBFAILED("FailedOperation.StartJobFailed"),
     
    // 当前状态冲突，不能执行该操作。
     FAILEDOPERATION_STATUSINCONFLICT("FailedOperation.StatusInConflict"),
     
    // 内部错误。
     INTERNALERROR("InternalError"),
     
    // 添加异步任务失败。
     INTERNALERROR_ADDTASKERROR("InternalError.AddTaskError"),
     
    // 内部调度系统错误。
     INTERNALERROR_CELERYERROR("InternalError.CeleryError"),
     
    // cgw系统错误。
     INTERNALERROR_CGWSYSTEMERROR("InternalError.CgwSystemError"),
     
    // 迁移平台数据库访问失败。
     INTERNALERROR_DATABASEERROR("InternalError.DatabaseError"),
     
    // 迁移任务冲突。
     INTERNALERROR_DUPLICATEJOB("InternalError.DuplicateJob"),
     
    // 锁冲突。
     INTERNALERROR_LOCKERROR("InternalError.LockError"),
     
    // 通信协议错误。
     INTERNALERROR_PROTOCOLERROR("InternalError.ProtocolError"),
     
    // 未知的内部错误。
     INTERNALERROR_UNKNOWNERROR("InternalError.UnknownError"),
     
    // 参数错误。
     INVALIDPARAMETER("InvalidParameter"),
     
    // 参数值错误。
     INVALIDPARAMETER_BIZINVALIDPARAMETERVALUEERROR("InvalidParameter.BizInvalidParameterValueError"),
     
    // 实例不存在。
     INVALIDPARAMETER_INSTANCENOTFOUND("InvalidParameter.InstanceNotFound"),
     
    // 参数值错误。
     INVALIDPARAMETERVALUE_INVALIDPARAMETERVALUE("InvalidParameterValue.InvalidParameterValue"),
     
    // 闲置迁移任务数目超过限制。
     LIMITEXCEEDED_MAXUNUSEDJOBS("LimitExceeded.MaxUnusedJobs"),
     
    // 操作被拒绝。
     OPERATIONDENIED("OperationDenied"),
     
    // 任务操作失败。
     OPERATIONDENIED_JOBOPERATIONDENIEDERROR("OperationDenied.JobOperationDeniedError"),
     
    // 数据迁移服务不支持当前迁移类型。
     OPERATIONDENIED_MIGRATESERVICESUPPORTERROR("OperationDenied.MigrateServiceSupportError"),
     
    // 该操作不能执行。
     OPERATIONDENIED_OPERATIONDENIED("OperationDenied.OperationDenied"),
     
    // 资源不存在。
     RESOURCENOTFOUND("ResourceNotFound"),
     
    // 未找到资源。
     RESOURCENOTFOUND_BIZRESOURCENOTFOUNDERROR("ResourceNotFound.BizResourceNotFoundError"),
     
    // 迁移任务不存在。
     RESOURCENOTFOUND_JOBNOTEXIST("ResourceNotFound.JobNotExist"),
     
    // 实例未找到。
     RESOURCENOTFOUND_RESOURCENOTFOUND("ResourceNotFound.ResourceNotFound"),
     
    // 认证失败，没有足够权限。
     UNAUTHORIZEDOPERATION_NOTENOUGHPRIVILEGES("UnauthorizedOperation.NotEnoughPrivileges"),
     
    // 操作不支持。
     UNSUPPORTEDOPERATION("UnsupportedOperation");
     
    private String value;
    private DtsErrorCode (String value){
        this.value = value;
    }
    /**
     * @return errorcode value
     */
    public String getValue() {
        return value;
    }
}
